==> libgphoto2_2.5.3.1.orig.tar.gz: libgphoto2-api.html/gphoto2-port_8c.js <==
var gphoto2_port_8c =
[
    [ "_GPPortPrivateCore", "struct__GPPortPrivateCore.html", "struct__GPPortPrivateCore" ],
    [ "_", "gphoto2-port_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "_BSD_SOURCE", "gphoto2-port_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "CHECK_INIT", "gphoto2-port_8c.html#a7dd9e079511891ec9996ebb25c0e6814", null ],
    [ "CHECK_NULL", "gphoto2-port_8c.html#a9abb452b72afcd88b55ba65065feff20", null ],
    [ "CHECK_RESULT", "gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
    [ "CHECK_SUPP", "gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a", null ],
    [ "FAST_TIMEOUT", "gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525", null ],
    [ "N_", "gphoto2-port_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "ngettext", "gphoto2-port_8c.html#a3011b7cb854d99053a2d68ff760179b4", null ],
    [ "gp_port_check_int", "gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277", null ],
    [ "gp_port_check_int_fast", "gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c", null ],
    [ "gp_port_close", "gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e", null ],
    [ "gp_port_flush", "gphoto2-port_8c.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d", null ],
    [ "gp_port_free", "gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5", null ],
    [ "gp_port_get_error", "gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828", null ],
    [ "gp_port_get_info", "gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a", null ],
    [ "gp_port_get_pin", "gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62", null ],
    [ "gp_port_get_settings", "gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0", null ],
    [ "gp_port_get_timeout", "gphoto2-port_8c.html#a2ae81836b1bca7ae97695d754cc9a3a6", null ],
    [ "gp_port_new", "gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5", null ],
    [ "gp_port_open", "gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957", null ],
    [ "gp_port_read", "gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d", null ],
    [ "gp_port_reset", "gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44", null ],
    [ "gp_port_seek", "gphoto2-port_8c.html#ac55c6bd131ac7ab047d8867c853b1bda", null ],
    [ "gp_port_send_break", "gphoto2-port_8c.html#aa5c3be2ad2546c829dc21d4d8fabb08d", null ],
    [ "gp_port_send_scsi_cmd", "gphoto2-port_8c.html#a56b83abbf58d7b01bdfd568bc3fff917", null ],
    [ "gp_port_set_error", "gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb", null ],
    [ "gp_port_set_info", "gphoto2-port_8c.html#a4a192eaac78b326ebe41e8e4441a38e4", null ],
    [ "gp_port_set_pin", "gphoto2-port_8c.html#afb74e804c7fdb8897736f811d8e2adae", null ],
    [ "gp_port_set_settings", "gphoto2-port_8c.html#a9503a6f8c4d87a2c22b802ce099cf8ef", null ],
    [ "gp_port_set_timeout", "gphoto2-port_8c.html#a68fb24a4f729ec5be85f4aedf3bb8e4f", null ],
    [ "gp_port_settings_get", "gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29", null ],
    [ "gp_port_settings_set", "gphoto2-port_8c.html#a4389daae7f57c7759775ad1dd512c70a", null ],
    [ "gp_port_timeout_get", "gphoto2-port_8c.html#addd41ab8b46062ec99cf07cafc12319d", null ],
    [ "gp_port_timeout_set", "gphoto2-port_8c.html#ae732282e180518c78a5854c023e20620", null ],
    [ "gp_port_usb_clear_halt", "gphoto2-port_8c.html#af410cacf6d6c44325b6637da95fc574d", null ],
    [ "gp_port_usb_find_device", "gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48", null ],
    [ "gp_port_usb_find_device_by_class", "gphoto2-port_8c.html#a5d67338933ddaed39c4fb20a23d76ec2", null ],
    [ "gp_port_usb_msg_class_read", "gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2", null ],
    [ "gp_port_usb_msg_class_write", "gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf", null ],
    [ "gp_port_usb_msg_interface_read", "gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4", null ],
    [ "gp_port_usb_msg_interface_write", "gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305", null ],
    [ "gp_port_usb_msg_read", "gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6", null ],
    [ "gp_port_usb_msg_write", "gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d", null ],
    [ "gp_port_write", "gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897", null ],
    [ "description", "gphoto2-port_8c.html#a68344fa88cf4e86b5079fd69a5c22d57", null ],
    [ "description_long", "gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca", null ],
    [ "description_short", "gphoto2-port_8c.html#afac0b65253b3a37c961828e88b453733", null ],
    [ "level", "gphoto2-port_8c.html#af3b9610f316d951aa2a99b225dba748a", null ],
    [ "number", "gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54", null ],
    [ "pin", "gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e", null ]
];

==> libgphoto2_2.5.9.orig.tar.gz: libgphoto2-api.html/gphoto2-port_8c.js <==
var gphoto2_port_8c =
[
    [ "_GPPortPrivateCore", "struct__GPPortPrivateCore.html", "struct__GPPortPrivateCore" ],
    [ "_", "gphoto2-port_8c.html#a32a3cf3d9dd914f5aeeca5423c157934", null ],
    [ "_BSD_SOURCE", "gphoto2-port_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73", null ],
    [ "CHECK_INIT", "gphoto2-port_8c.html#a7dd9e079511891ec9996ebb25c0e6814", null ],
    [ "CHECK_RESULT", "gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d", null ],
    [ "CHECK_SUPP", "gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a", null ],
    [ "FAST_TIMEOUT", "gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525", null ],
    [ "LOG_DATA", "gphoto2-port_8c.html#a828c4f99cd2fcdbf9b83793b1c7e7ccb", null ],
    [ "N_", "gphoto2-port_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
    [ "ngettext", "gphoto2-port_8c.html#a3011b7cb854d99053a2d68ff760179b4", null ],
    [ "gp_port_check_int", "gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277", null ],
    [ "gp_port_check_int_fast", "gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c", null ],
    [ "gp_port_close", "gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e", null ],
    [ "gp_port_flush", "gphoto2-port_8c.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d", null ],
    [ "gp_port_free", "gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5", null ],
    [ "gp_port_get_error", "gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828", null ],
    [ "gp_port_get_info", "gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a", null ],
    [ "gp_port_get_pin", "gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62", null ],
    [ "gp_port_get_settings", "gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0", null ],
    [ "gp_port_get_timeout", "gphoto2-port_8c.html#a2ae81836b1bca7ae97695d754cc9a3a6", null ],
    [ "gp_port_new", "gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5", null ],
    [ "gp_port_open", "gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957", null ],
    [ "gp_port_read", "gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d", null ],
    [ "gp_port_reset", "gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44", null ],
    [ "gp_port_seek", "gphoto2-port_8c.html#ac55c6bd131ac7ab047d8867c853b1bda", null ],
    [ "gp_port_send_break", "gphoto2-port_8c.html#aa5c3be2ad2546c829dc21d4d8fabb08d", null ],
    [ "gp_port_send_scsi_cmd", "gphoto2-port_8c.html#a56b83abbf58d7b01bdfd568bc3fff917", null ],
    [ "gp_port_set_error", "gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb", null ],
    [ "gp_port_set_info", "gphoto2-port_8c.html#a4a192eaac78b326ebe41e8e4441a38e4", null ],
    [ "gp_port_set_pin", "gphoto2-port_8c.html#afb74e804c7fdb8897736f811d8e2adae", null ],
    [ "gp_port_set_settings", "gphoto2-port_8c.html#a9503a6f8c4d87a2c22b802ce099cf8ef", null ],
    [ "gp_port_set_timeout", "gphoto2-port_8c.html#a68fb24a4f729ec5be85f4aedf3bb8e4f", null ],
    [ "gp_port_settings_get", "gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29", null ],
    [ "gp_port_settings_set", "gphoto2-port_8c.html#a4389daae7f57c7759775ad1dd512c70a", null ],
    [ "gp_port_timeout_get", "gphoto2-port_8c.html#addd41ab8b46062ec99cf07cafc12319d", null ],
    [ "gp_port_timeout_set", "gphoto2-port_8c.html#ae732282e180518c78a5854c023e20620", null ],
    [ "gp_port_usb_clear_halt", "gphoto2-port_8c.html#af410cacf6d6c44325b6637da95fc574d", null ],
    [ "gp_port_usb_find_device", "gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48", null ],
    [ "gp_port_usb_find_device_by_class", "gphoto2-port_8c.html#a5d67338933ddaed39c4fb20a23d76ec2", null ],
    [ "gp_port_usb_msg_class_read", "gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2", null ],
    [ "gp_port_usb_msg_class_write", "gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf", null ],
    [ "gp_port_usb_msg_interface_read", "gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4", null ],
    [ "gp_port_usb_msg_interface_write", "gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305", null ],
    [ "gp_port_usb_msg_read", "gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6", null ],
    [ "gp_port_usb_msg_write", "gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d", null ],
    [ "gp_port_write", "gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897", null ],
    [ "description", "gphoto2-port_8c.html#a68344fa88cf4e86b5079fd69a5c22d57", null ],
    [ "description_long", "gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca", null ],
    [ "description_short", "gphoto2-port_8c.html#afac0b65253b3a37c961828e88b453733", null ],
    [ "level", "gphoto2-port_8c.html#af3b9610f316d951aa2a99b225dba748a", null ],
    [ "number", "gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54", null ],
    [ "pin", "gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e", null ]
];
